=========
ChangeLog
=========


v0.3.1
======

* Corrected egg packaging to include .txt and .rst files
* Corrected `distribute` dependency for py2 vs. py3


v0.2.0
======

* Fixed issue #2
* Added python 3 compatibility
* First tagged release
